﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace NewRecipeGrid
{
   public abstract class VMBase : INotifyPropertyChanged
        {
            public event PropertyChangedEventHandler PropertyChanged;
            public void RaisePropertyChanged(String propertyName)
            {
                var handler = this.PropertyChanged;
                if (handler != null)
                    handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        public class Recipe : VMBase
        {
            public String Name { get; set; }
            ObservableCollection<RecipeParameter> parameters;
            public ObservableCollection<RecipeParameter> Parameters { get { return parameters; } set { parameters = value; RaisePropertyChanged("Parameters"); } }
        }

        public class RecipeParameter : VMBase
        {
            public string ComponentName { get; set; }
            public string Name { get; set; }

            ObservableCollection<StepValue> values;

            public ObservableCollection<StepValue> Values { get { return values; } set { values = value; RaisePropertyChanged("Values"); } }

        }

        public class StepValue : VMBase
        {
            int v;
            public int StepId { get; set; }
            public int Value { get { return v; } set { v = value; RaisePropertyChanged("Value"); } }
        }

        public class RecipeViewModel : VMBase
        {
            Recipe recipe;
            public Recipe Recipe
            {
                get { return recipe; }
                set { recipe = value; }
            }
            public RecipeViewModel()
            {
                PopulateRecipe();
            }
            void PopulateRecipe()
            {
                recipe = new Recipe();
                recipe.Parameters = new ObservableCollection<RecipeParameter>();
                int groupId = 1;
                int groupItems = 0;
                for (int p = 1; p <= 200; p++)
                {
                    var parameter = new RecipeParameter();
                    parameter.Name = "Parameter " + p.ToString();
                    parameter.Values = new ObservableCollection<StepValue>();
                    if (groupItems == 10)
                    {
                        groupId++;
                        groupItems = 1;
                    }
                    parameter.ComponentName = "Component #" + groupId.ToString();
                    for (int s = 1; s <= 200; s++)
                    {
                        StepValue value = new StepValue();
                        value.StepId = s;
                        value.Value = s * 10;
                        parameter.Values.Add(value);
                    }

                    recipe.Parameters.Add(parameter);
                    groupItems++;
                }
            }

            public void ChangeValue()
            {
                recipe.Parameters[11].Values[3].Value += 100;
            }
        }
}
